# Changelog

## [0.7.0] - 2021-12-26

* Accept both single and double quotes ([#9](https://github.com/tonyo/django-migration-checker/pull/9))
* Drop support for Python 2.7 and 3.5
* Move to GitHub Actions
* Get rid of Travis


## [0.6.0] - 2020-12-05

* Exit with code 1 when conflicts are found ([#7](https://github.com/tonyo/django-migration-checker/pull/7))


## [0.1.0] - 2016-09-09

* First release on PyPI.
